@@ -64,6 +64,7 @@ as_lpp <- function(x, ...){
 
 as_gn.linnet <- function(x, ..., spatstat = FALSE){
   if (!inherits(x, "linnet")) stop("x muss be of class 'linnet'")
+  if (!is.logical(spatstat)) stop ("spatstat must be logical")
   l <- a1 <- a2 <- e <- NULL
   L <- x
   d <- diag(L$dpath[L$from, L$to])
@@ -194,6 +195,7 @@ as_gn.lpp <- function(x, ..., spatstat = FALSE) {
   if (!inherits(x, "lpp")){
     stop("Object must be of class 'lpp'")
   }
+  if (!is.logical(spatstat)) stop ("spatstat must be logical")
   L <- as.linnet(x)
   as_gn(L, spatstat = spatstat)
 }
@@ -222,6 +224,7 @@ as_gnpp.lpp <- function(x, ..., spatstat = FALSE){
   if (!inherits(x, "lpp")){
       stop("Object must be of class 'lpp'")
   }
+  if (!is.logical(spatstat)) stop ("spatstat must be logical")
   G <- as_gn(as.linnet(x), spatstat = spatstat)
   data <- tibble(l = x$data$seg, tp_l = x$data$tp,
                 xx = x$data$x, y = x$data$y)
@@ -272,6 +275,9 @@ as_gnpp.lpp <- function(x, ..., spatstat = FALSE){
 
 as.linnet.gn <- function(X, ...) {
   l <- a2 <- NULL
+  if (!inherits(X, "gn")){
+    stop("Object must be of class 'gn'")
+  }
   window <- owin(xrange = range(X$vertices$x),
                  yrange = range(X$vertices$y))
   vertices <- ppp(x = X$vertices$x, y = X$vertices$y, window = window)
@@ -304,6 +310,9 @@ as.linnet.gn <- function(X, ...) {
 #' all.equal(x, L)
 
 as_lpp.gnpp <- function(x, ...) {
+  if (!inherits(x, "gnpp")){
+    stop("Object must be of class 'gnpp'")
+  }
   L <- as.linnet(as_gn(x))
   data <- x$data
   marks <- NULL
@@ -314,7 +323,6 @@ as_lpp.gnpp <- function(x, ...) {
 }
 
 #' @rdname as_gn
-#' @export
 
 as_gn.lppfit <- function(x, ...) {
   x$network
