@@ -2,6 +2,6 @@ library(geonet)
 library(spatstat)
 
 test_that("test",{
-  X <- as.gn(simplenet)
+  X <- as_gn(simplenet)
   expect_s3_class(X, "gn")
 })
